pub(crate) struct ContainingBlock {
scroll_node_id: ScrollTreeNodeId,
scroll_frame_size: Option<LayoutSize>,
clip_id: ClipId,
rect: PhysicalRect<Au>,
accumulated_reference_frame_offset: PhysicalVec<Au>,
established_scroll_frame: bool,
}Fields
scroll_node_id: ScrollTreeNodeIdThe SpatialId of the spatial node that contains the children of this containing block.
scroll_frame_size: Option<LayoutSize>The size of the parent scroll frame of this containing block, used for resolving sticky margins. If this is None, then this is a direct descendant of a reference frame and sticky positioning isn’t taken into account.
clip_id: ClipIdThe ClipId to use for the children of this containing block.
rect: PhysicalRect<Au>The physical rect of this containing block.
accumulated_reference_frame_offset: PhysicalVec<Au>Normally containing block offsets and display list items are positioned relative to their parent reference frame, but cumulative containing block boundaries on fragments need to disregard reference frames entirely. This value tracks the accumulated offset from the origin of the parent reference frame of this containing block.
established_scroll_frame: boolWhether current containing block established a scroll frame.
Implementations
Sourceimpl ContainingBlock
impl ContainingBlock
pub(crate) fn new( rect: PhysicalRect<Au>, scroll_node_id: ScrollTreeNodeId, scroll_frame_size: Option<LayoutSize>, clip_id: ClipId, accumulated_reference_frame_offset: PhysicalVec<Au>, established_scroll_frame: bool, ) -> Self
pub(crate) fn new_replacing_rect(&self, rect: &PhysicalRect<Au>) -> Self